@@ -1,8 +1,6 @@
-#!/usr/bin/env python
-
-#  Copyright 2022 Commonwealth Scientific and Industrial Research
+#  Copyright © 2018-2025 Commonwealth Scientific and Industrial Research
 #  Organisation (CSIRO) ABN 41 687 119 230.
-#
+# 
 #  Licensed under the Apache License, Version 2.0 (the "License");
 #  you may not use this file except in compliance with the License.
 #  You may obtain a copy of the License at
@@ -17,9 +15,7 @@
 
 import os
 
-from pathling import PathlingContext
-from pathling.coding import Coding
-from pathling.functions import to_coding
+from pathling import PathlingContext, Coding, to_coding, subsumes
 
 HERE = os.path.abspath(os.path.dirname(__file__))
 
@@ -33,19 +29,22 @@ cross_join = first_3.selectExpr(
     "CODE as LEFT", "DESCRIPTION as LEFT_DESCRIPTION"
 ).crossJoin(first_3.selectExpr("CODE as RIGHT", "DESCRIPTION as RIGHT_DESCRIPTION"))
 
-result_1 = pc.subsumes(
-    cross_join,
+result_1 = cross_join.withColumn(
     "SUBSUMES",
-    left_coding_column=to_coding(cross_join.LEFT, "http://snomed.info/sct"),
-    right_coding_column=to_coding(cross_join.RIGHT, "http://snomed.info/sct"),
+    subsumes(
+        to_coding(cross_join.LEFT, "http://snomed.info/sct"),
+        to_coding(cross_join.RIGHT, "http://snomed.info/sct"),
+    ),
 )
-result_2 = pc.subsumes(
-    result_1,
+result_2 = result_1.withColumn(
     "LEFT_IS_ENT",
-    # 232208008 |Ear, nose and throat disorder|
-    left_coding=Coding("http://snomed.info/sct", "232208008"),
-    right_coding_column=to_coding(cross_join.LEFT, "http://snomed.info/sct"),
+    subsumes(
+        # 232208008 |Ear, nose and throat disorder|
+        Coding("http://snomed.info/sct", "232208008"),
+        to_coding(cross_join.LEFT, "http://snomed.info/sct"),
+    ),
 )
+
 result_2.select(
     "LEFT", "RIGHT", "LEFT_DESCRIPTION", "RIGHT_DESCRIPTION", "SUBSUMES", "LEFT_IS_ENT"
 ).show()
