@@ -1,6 +1,6 @@
-#  Copyright 2023 Commonwealth Scientific and Industrial Research
+#  Copyright © 2018-2025 Commonwealth Scientific and Industrial Research
 #  Organisation (CSIRO) ABN 41 687 119 230.
-#
+# 
 #  Licensed under the Apache License, Version 2.0 (the "License");
 #  you may not use this file except in compliance with the License.
 #  You may obtain a copy of the License at
@@ -13,22 +13,24 @@
 #  See the License for the specific language governing permissions and
 #  limitations under the License.
 
-import logging
-from typing import Optional, Sequence
-
-from deprecated import deprecated
-
 # noinspection PyPackageRequirements
-from py4j.java_gateway import JavaObject
-from pyspark.sql import DataFrame, SparkSession, Column
 
-from pathling.coding import Coding
-from pathling.etc import find_jar
+from py4j.java_gateway import JavaObject
+from pyspark.sql import DataFrame, SparkSession
+from typing import Optional, Sequence, TYPE_CHECKING
+
+from pathling._version import (
+    __java_version__,
+    __scala_version__,
+    __delta_version__,
+    __hadoop_version__,
+)
 from pathling.fhir import MimeType
 
-__all__ = ["PathlingContext"]
+if TYPE_CHECKING:
+    from .datasource import DataSources
 
-EQ_EQUIVALENT = "equivalent"
+__all__ = ["PathlingContext"]
 
 
 class StorageType:
@@ -96,7 +98,11 @@ class PathlingContext:
         client_secret: Optional[str] = None,
         scope: Optional[str] = None,
         token_expiry_tolerance: Optional[int] = 120,
-        logging_level: Optional[int] = logging.INFO,
+        accept_language: Optional[str] = None,
+        enable_delta=False,
+        enable_remote_debugging: Optional[bool] = False,
+        debug_port: Optional[int] = 5005,
+        debug_suspend: Optional[bool] = True,
     ) -> "PathlingContext":
         """
         Creates a :class:`PathlingContext` with the given configuration options. This should only
@@ -114,7 +120,8 @@ class PathlingContext:
         classpath. You can get the path for the JAR (which is bundled with the Python package)
         using the `pathling.etc.find_jar` method.
 
-        :param spark: The :class:`SparkSession` instance.
+        :param spark: a pre-configured :class:`SparkSession` instance, use this if you need to
+               control the way that the session is set up
         :param max_nesting_level: controls the maximum depth of nested element data that is encoded
                upon import. This affects certain elements within FHIR resources that contain
                recursive references, e.g. `QuestionnaireResponse.item
@@ -130,7 +137,10 @@ class PathlingContext:
                server can use to resolve terminology queries. The default server is suitable for
                testing purposes only.
         :param terminology_verbose_request_logging: setting this option to `True` will enable
-               additional logging of the details of requests to the terminology service
+               additional logging of the details of requests to the terminology service. Note that
+               logging is subject to the Spark logging level, which you can set using
+               `SparkContext.setLogLevel`. Verbose request logging is sent to the `DEBUG` logging
+               level.
         :param terminology_socket_timeout: the maximum period (in milliseconds) that the server
                should wait for incoming data from the HTTP service
         :param max_connections_total: the maximum total number of connections for the client
@@ -156,21 +166,48 @@ class PathlingContext:
         :param scope: a scope value for use with the client credentials grant
         :param token_expiry_tolerance: the minimum number of seconds that a token should have
                before expiry when deciding whether to send it with a terminology request
-        :param logging_level: the logging level to use
+        :param accept_language: the default value of the Accept-Language HTTP header passed to
+               the terminology server. The value may contain multiple languages, with weighted
+               preferences as defined in
+               https://www.rfc-editor.org/rfc/rfc9110.html#name-accept-language. If not provided,
+               the header is not sent. The server can use the header to return the result in the
+               preferred language if it is able. The actual behaviour may depend on the server
+               implementation and the code systems used.
+        :param enable_delta: enables the use of Delta for storage of FHIR data.
+               Only supported when no SparkSession is provided.
+        :param enable_remote_debugging: enables remote debugging for the JVM process.
+        :param debug_port: the port for the debugger to listen on (default: 5005)
+        :param debug_suspend: if true, the JVM will suspend until a debugger is attached
         :return: a :class:`PathlingContext` instance initialized with the specified configuration
         """
-        spark = (
-            spark
-            or SparkSession.getActiveSession()
-            or SparkSession.builder.config("spark.jars", find_jar()).getOrCreate()
-        )
-        jvm = spark._jvm
 
-        # Configure logging.
-        jvm.py4j.GatewayServer.turnLoggingOn()
-        logger = logging.getLogger("py4j")
-        logger.setLevel(logging_level)
-        logger.addHandler(logging.StreamHandler())
+        def _new_spark_session():
+            spark_builder = (
+                SparkSession.builder.config(
+                    "spark.jars.packages",
+                    f"au.csiro.pathling:library-runtime:{__java_version__},"
+                    f"io.delta:delta-spark_{__scala_version__}:{__delta_version__},"
+                    f"org.apache.hadoop:hadoop-aws:{__hadoop_version__}",
+                )
+                .config(
+                    "spark.sql.extensions", "io.delta.sql.DeltaSparkSessionExtension"
+                )
+                .config(
+                    "spark.sql.catalog.spark_catalog",
+                    "org.apache.spark.sql.delta.catalog.DeltaCatalog",
+                )
+            )
+
+            # Add remote debugging configuration if enabled
+            if enable_remote_debugging:
+                suspend_option = "y" if debug_suspend else "n"
+                debug_options = f"-agentlib:jdwp=transport=dt_socket,server=y,suspend={suspend_option},address={debug_port}"
+                spark_builder = spark_builder.config("spark.driver.extraJavaOptions", debug_options)
+
+            return spark_builder.getOrCreate()
+
+        spark = spark or SparkSession.getActiveSession() or _new_spark_session()
+        jvm = spark._jvm
 
         # Build an encoders configuration object from the provided parameters.
         encoders_config = (
@@ -230,6 +267,7 @@ class PathlingContext:
             .client(client_config)
             .cache(cache_config)
             .authentication(auth_config)
+            .acceptLanguage(accept_language)
             .build()
         )
 
@@ -253,6 +291,12 @@ class PathlingContext:
             self._spark._wrapped if hasattr(self._spark, "_wrapped") else self._spark,
         )
 
+    def version(self):
+        """
+        :return: The version of the Pathling library.
+        """
+        return self._jpc.getVersion()
+
     def encode(
         self,
         df: DataFrame,
@@ -308,107 +352,12 @@ class PathlingContext:
             )
         )
 
-    @deprecated(reason="You should use the 'udfs.member_of' UDF instead")
-    def member_of(
-        self,
-        df: DataFrame,
-        coding_column: Column,
-        value_set_uri: str,
-        output_column_name: str,
-    ):
-        """
-        Takes a dataframe with a Coding column as input. A new column is created which contains a
-        Boolean value, indicating whether the input Coding is a member of the specified FHIR
-        ValueSet.
 
-        :param df: a DataFrame containing the input data
-        :param coding_column: a Column containing a struct representation of a Coding
-        :param value_set_uri: an identifier for a FHIR ValueSet
-        :param output_column_name: the name of the result column
-        :return: A new dataframe with an additional column containing the result of the operation
+    @property
+    def read(self) -> "DataSources":
         """
-        return self._wrap_df(
-            self._jpc.memberOf(
-                df._jdf, coding_column._jc, value_set_uri, output_column_name
-            )
-        )
+        Provides access to the instance of :class:`DataSource` factory.
+        """
+        from pathling.datasource import DataSources
 
-    @deprecated(reason="You should use the 'udfs.translate' UDF instead")
-    def translate(
-        self,
-        df: DataFrame,
-        coding_column: Column,
-        concept_map_uri: str,
-        reverse: Optional[bool] = False,
-        equivalence: Optional[str] = EQ_EQUIVALENT,
-        target: Optional[str] = None,
-        output_column_name: Optional[str] = "result",
-    ):
-        """
-        Takes a dataframe with a Coding column as input. A new column is created which contains
-        the array of Codings value with translation targets from the specified FHIR ConceptMap.
-        There may be more than one target concept for each input concept.
-
-        :param df: a DataFrame containing the input data
-        :param coding_column: a Column containing a struct representation of a Coding
-        :param concept_map_uri: an identifier for a FHIR ConceptMap
-        :param reverse: the direction to traverse the map - false results in "source to target"
-               mappings, while true results in "target to source"
-        :param equivalence: a comma-delimited set of values from the ConceptMapEquivalence ValueSet
-        :param target: identifies the value set in which a translation is sought.  If there is no
-               target specified, the server should return all known translations.
-        :param output_column_name: the name of the result column
-        :return: A new dataframe with an additional column containing the result of the operation.
-        """
-        return self._wrap_df(
-            self._jpc.translate(
-                df._jdf,
-                coding_column._jc,
-                concept_map_uri,
-                reverse,
-                equivalence,
-                target,
-                output_column_name,
-            )
-        )
-
-    @deprecated(reason="You should use the 'udfs.subsumes' UDF instead")
-    def subsumes(
-        self,
-        df: DataFrame,
-        output_column_name: str,
-        left_coding_column: Optional[Column] = None,
-        right_coding_column: Optional[Column] = None,
-        left_coding: Optional[Coding] = None,
-        right_coding: Optional[Coding] = None,
-    ):
-        """
-        Takes a dataframe with two Coding columns. A new column is created which contains a
-        Boolean value, indicating whether the left Coding subsumes the right Coding.
-
-        :param df: a DataFrame containing the input data
-        :param left_coding_column: a Column containing a struct representation of a Coding,
-               for the left-hand side of the subsumption test
-        :param right_coding_column: a Column containing a struct representation of a Coding,
-               for the right-hand side of the subsumption test
-        :param left_coding: a Coding object for the left-hand side of the subsumption test
-        :param right_coding: a Coding object for the right-hand side of the subsumption test
-        :param output_column_name: the name of the result column
-        :return: A new dataframe with an additional column containing the result of the operation.
-        """
-        if (left_coding_column is None and left_coding is None) or (
-            right_coding_column is None and right_coding is None
-        ):
-            raise ValueError(
-                "Must provide either left_coding_column or left_coding, and either "
-                "right_coding_column or right_coding"
-            )
-        left_column = left_coding.to_literal() if left_coding else left_coding_column
-        right_column = (
-            right_coding.to_literal() if right_coding else right_coding_column
-        )
-        return self._wrap_df(
-            self._jpc.subsumes(
-                df._jdf, left_column._jc, right_column._jc, output_column_name
-            )
-        )
+        return DataSources(self)
